@@ -116,7 +116,8 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
 
         if self.subnet:
             vpc = self.ec2_backend.get_vpc(self.subnet.vpc_id)
-            if vpc and vpc.enable_dns_hostnames:
+            # FIXME: Drop the `in` clause once the Vpc attribute is properly typed.
+            if vpc and vpc.enable_dns_hostnames in [True, "True", "true"]:
                 self.private_dns_name = generate_dns_from_ip(self.private_ip_address)
                 for address in self.private_ip_addresses:
                     if address.get("Primary", None):
@@ -204,6 +205,8 @@ class NetworkInterface(TaggedEC2Resource, CloudFormationModel):
 
     def delete(self) -> None:
         self.ec2_backend.delete_network_interface(eni_id=self.id)
+        for priv_ip in self.private_ip_addresses:
+            self.subnet.del_subnet_ip(priv_ip["PrivateIpAddress"])
 
     def stop(self) -> None:
         if self.public_ip_auto_assign:
