@@ -21,7 +21,7 @@ class TransitGateway(TaggedEC2Resource, CloudFormationModel):
         "DnsSupport": "enable",
         "MulticastSupport": "disable",
         "PropagationDefaultRouteTableId": "tgw-rtb-0d571391e50cf8514",
-        "TransitGatewayCidrBlocks": None,
+        "TransitGatewayCidrBlocks": [],
         "VpnEcmpSupport": "enable",
     }
 
@@ -38,12 +38,16 @@ class TransitGateway(TaggedEC2Resource, CloudFormationModel):
         self.options = merge_multiple_dicts(self.DEFAULT_OPTIONS, options or {})
         self._created_at = utcnow()
 
+    @property
+    def tags(self) -> List[Dict[str, str]]:
+        return self.get_tags()
+
     @property
     def physical_resource_id(self) -> str:
         return self.id
 
     @property
-    def create_time(self) -> str:
+    def creation_time(self) -> str:
         return iso_8601_datetime_with_milliseconds(self._created_at)
 
     @property
@@ -52,7 +56,7 @@ class TransitGateway(TaggedEC2Resource, CloudFormationModel):
 
     @property
     def arn(self) -> str:
-        return f"arn:aws:ec2:{self.ec2_backend.region_name}:{self.ec2_backend.account_id}:transit-gateway/{self.id}"
+        return f"arn:{self.ec2_backend.partition}:ec2:{self.ec2_backend.region_name}:{self.ec2_backend.account_id}:transit-gateway/{self.id}"
 
     @staticmethod
     def cloudformation_name_type() -> str:
